<!DOCTYPE html>
<html>
  <head>
    <title>TEI</title>
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <style>

      html {
        background-color: #f7f7f7;
      }

      li {
        list-style-type: none
      }

      ul {
        margin-left: 0;
        padding-left: 0
      }

      .grid {
        display: grid;
        grid-template-columns: 25% 65%;
        grid-column-gap: 5em;
        height: 100%;
      }

      #col-main {
        margin-top: 10px;
        box-shadow: -5px 0 15px -5px #dfe3eb, 5px 0 15px -5px #dfe3eb;
        padding: 3em;
        overflow-y: scroll; 
        height: calc(100vh - 30px);
        background-color: #ffffff;
      }

      .sidenav {
        height: calc(100vh - 30px);
        background-color: #ffffff;
        padding-top: 20px;
        position: -webkit-sticky;
        position: sticky;
        top: 0;
        margin-top: 10px;
        margin-left: 10px;
      }

      a {
        text-decoration: none;
        color:  #000000 !important;
      }

      #mySidebar a:hover {
        background: #dfe3eb;
        width: auto;
      }

      #mySidebar a {
        display: block;
        padding: 6px;
        padding-left: 3em;
        font-size: 12pt;
      }

      .inner_link {
        border-bottom: 1px dotted #000;
        text-decoration: none;
      }

    </style>
  </head>
    
  <body>
    <main>
  

      <div class="main">
        <div class="grid">
          <div id="col-left" class="column">
            <div class="sidenav" id="mySidebar">
              <ul>
                <li>
                  <a href="#nav-tabContent">
                    &#94; Back to the beginning
                  </a>
                </li>
              </ul>
            </div>
          </div>
          <div id="col-main" class="column">
            <div class="container">
              <div class="main" id="nav-tabContent"></div>
            </div>
          </div>
        </div>
      </div>
         
    </main>
  
    <script></script>

  </body>
</html>
