<!DOCTYPE html>
<html>
  <head>
    <title>TEI</title>
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <link rel="stylesheet" href="https://www.w3schools.com/w3css/4/w3.css"/>
    <style>
      .grid {
        display: grid;
        grid-template-columns: 15% 70%;
        grid-column-gap: 10px;
      }

      #col-main{
        padding: 2em;
        overflow-y: scroll; 
        height: calc(100vh - 70px);
      }

      #mySidebar {
        background-color: #f1f6f9;
      }

      a {
        text-decoration: none;
        color:  #000000 !important;
      }

      #mySidebar a:hover {
        background: #f1f6f9;
        border-radius: 1000px;
      }

      #mySidebar a {
        display: block;
        padding: 6px;
        margin-left: 3em;
      }

      #col-main {
       margin-top: 10px;
       box-shadow: -5px 0 15px -5px #9ba4b4, 5px 0 15px -5px #9ba4b4;
      }

    </style>
  </head>

  <body>
    <main>

      <div class="w3-sidebar w3-bar-block w3-card w3-animate-left" style="display:none" id="mySidebar">
        <button class="w3-bar-item w3-button w3-large" onclick="w3_close()">
          <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-double-left" viewBox="0 0 16 16">
          <path fill-rule="evenodd" d="M8.354 1.646a.5.5 0 0 1 0 .708L2.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/>
          <path fill-rule="evenodd" d="M12.354 1.646a.5.5 0 0 1 0 .708L6.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"/>
        </svg>
        Close
      </button>
        <ul>
          <li>
            <a href="#nav-tabContent">
              <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-arrow-bar-up" viewBox="0 0 16 16">
              <path fill-rule="evenodd" d="M8 10a.5.5 0 0 0 .5-.5V3.707l2.146 2.147a.5.5 0 0 0 .708-.708l-3-3a.5.5 0 0 0-.708 0l-3 3a.5.5 0 1 0 .708.708L7.5 3.707V9.5a.5.5 0 0 0 .5.5zm-7 2.5a.5.5 0 0 1 .5-.5h13a.5.5 0 0 1 0 1h-13a.5.5 0 0 1-.5-.5z"/>
            </svg>  
              Back to the beginning
            </a>
          </li>
        </ul>
      </div>

      <div id="main">

        <div class="w3-teal">
          <button id="openNav" class="w3-button w3-teal w3-xlarge" onclick="w3_open()">&#9776;</button>
          <div class="w3-container">
          </div>
        </div>

        <div class="grid">
          <div id="col-left" class="column"> </div>
          <div id="col-main" class="column">
            <div class="w3-container">
              <div class="main" id="nav-tabContent"></div>
            </div>
          </div>
        </div>

      </div>

    </main>
  
    <script>
    function w3_open() {
      document.getElementById("main").style.marginLeft = "25%";
      document.getElementById("mySidebar").style.width = "25%";
      document.getElementById("mySidebar").style.display = "block";
      document.getElementById("openNav").style.display = 'none';
    }
    function w3_close() {
      document.getElementById("main").style.marginLeft = "0%";
      document.getElementById("mySidebar").style.display = "none";
      document.getElementById("openNav").style.display = "inline-block";
    }
    </script>

  </body>
</html>